package main

import (
	"context"

	"github.com/camunda-cloud/zeebe/clients/go/pkg/entities"
	"github.com/camunda-cloud/zeebe/clients/go/pkg/zbc"
	"gitlab.mashroom.com/mashroom/backend/common/generic/bpms"
	identity "gitlab.mashroom.com/mashroom/backend/identity/api"
	"gitlab.mashroom.com/mashroom/backend/identity/internal/model"
	"gitlab.mashroom.com/mashroom/backend/identity/internal/service"
)

func serveBPMS(srv service.Service) (zbc.Client, error) {
	client, err := bpms.ServeBpms("identity-service", bpms.MapHandler(map[string]bpms.Registrator{
		"request-tenant-check": func() (request interface{}, processor bpms.Processor) {
			req := &identity.TenantsInviteRequest{}

			return req, func(
				ctx context.Context,
				job entities.Job,
			) (reply interface{}, enhance map[string]interface{}, err error) {
				_, err = srv.TenantsInvite(ctx, req)

				return nil, nil, err
			}
		},
		"skip-checks": func() (request interface{}, processor bpms.Processor) {
			req := &struct {
				Offer string `json:"offer"`
			}{}

			return req, func(
				ctx context.Context,
				job entities.Job,
			) (reply interface{}, enhance map[string]interface{}, err error) {
				err = srv.SkipChecks(ctx, model.PollingTypeTenant, req.Offer)

				return nil, nil, err
			}
		},
	}))

	return client, err
}
