// Package model provides model abstraction for persistent data
package model

import (
	"context"
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// PollingType enum
type PollingType int

// PollingType values
const (
	PollingTypeInvalid PollingType = iota
	PollingTypeTenant
	PollingTypeLandlord
)

// Repository provides persistent operations interface
type Repository interface {
	Migrate(ctx context.Context) error
	SanctionSave(ctx context.Context, sanction *Sanction) error
	SanctionRemoveByMinVersion(ctx context.Context, min time.Time) error
	SanctionCountByName(ctx context.Context, names ...string) (int, error)
	PollingInsert(ctx context.Context, typ PollingType, polling *Polling) error
	PollingGetByRequestID(ctx context.Context, requestID string) (*Polling, error)
	PollingGetByTypeRequestID(ctx context.Context, typ PollingType, requestID string) (*Polling, error)
	PollingListByTypeLastPolled(ctx context.Context, typ PollingType, max time.Time) ([]*Polling, error)
	PollingUpdate(ctx context.Context, polling *Polling) error
	PollingUpdateLastPolledByTypeID(ctx context.Context, typ PollingType, id primitive.ObjectID, t time.Time) error
	PollingRemoveByTypeID(ctx context.Context, typ PollingType, id primitive.ObjectID) error
	PollingRemoveByTypeOffer(ctx context.Context, typ PollingType, offer string) error
}
