// Package rentprofile provides client to interact with RentProfile service provider.
// See API documentation at https://www.rentprofile.co/api/documentation
package rentprofile

import (
	"context"
	"fmt"
	"net/http"
)

// DefaultURL default rentprofile API URL
const DefaultURL = "https://www.rentprofile.co/v1/api/"

// TenantStatusComplete successful check status
var TenantStatusComplete = "Complete"

// Client for rentprofile service
type Client interface {
	Invite(ctx context.Context, req *InviteRequest) (*InviteResponse, error)
	Status(ctx context.Context, req *StatusRequest) (*StatusResponse, error)
	Result(ctx context.Context, req *ResultRequest) (*ResultResponse, error)
}

// Config for rentprofile client
type Config struct {
	HTTPClient *http.Client
	Key        string
	URL        string
}

func validateConfig(config *Config) error {
	if config == nil {
		return fmt.Errorf("invalid rentprofile client config")
	}

	if config.URL == "" {
		return fmt.Errorf("invalid rentprofile client URL")
	}

	if config.HTTPClient == nil {
		return fmt.Errorf("invalid rentprofile client HTTP client")
	}

	if config.Key == "" {
		return fmt.Errorf("invalid rentprofile client API key")
	}

	return nil
}

// New returns new rentprofile client instance
func New(config *Config) (Client, error) {
	err := validateConfig(config)
	if err != nil {
		return nil, err
	}

	return &clientImpl{
		Config: *config,
	}, nil
}
