package rentprofile

// BooleanString string-represented boolean type
type BooleanString string

// BooleanString values
var (
	BooleanTrue  BooleanString = "true"
	BooleanFalse BooleanString = "false"
)

// BaseRequest with rentprofile API key
type BaseRequest struct {
	APIKey string `json:"api_key"`
}

// ResultRequest check result request
type ResultRequest struct {
	BaseRequest
	RequestID   string        `json:"request_id"`
	PDFRequired BooleanString `json:"pdf_required"`
}

// ResultResponse check result response
type ResultResponse struct {
	RequestID    string `json:"request_id"`
	PDFURL       string `json:"pdf_url"`
	Name         string `json:"name"`
	EmailAddress string `json:"email_address"`
	RiskScore    string `json:"risk_score"`
}

// InviteRequest check initiation request
type InviteRequest struct {
	AddressLine1 string
	Postcode     string
	Applicants   []*InviteRequestApplicant
	TotalRent    int
}

// InviteRequestApplicant party for check initiation
type InviteRequestApplicant struct {
	Name           string
	Email          string
	Mobile         string
	IsGuarantorFor string
}

// InviteResponse check initiation response
type InviteResponse struct {
	Applicants []*InviteResponseApplicant
}

// InviteResponseApplicant party ID for check initiation
type InviteResponseApplicant struct {
	Name      string
	RequestID string
}

// StatusRequest check status request
type StatusRequest struct {
	BaseRequest
	RequestID string `json:"request_id"`
}

// StatusResponse check status response
type StatusResponse struct {
	RequestID   string `json:"request_id"`
	InviteDate  string `json:"invite_date"`
	ProfileLink string `json:"profile_link"`
	Status      string `json:"status"`
}
