package service

import (
	"context"
	"time"

	"gitlab.mashroom.com/mashroom/backend/common/generic/log"
	"gitlab.mashroom.com/mashroom/backend/identity/internal/model"
)

func (srv *serviceImpl) PollStatusChanges(ctx context.Context, max time.Time) error {
	polls, err := srv.Repository.PollingListByTypeLastPolled(ctx, model.PollingTypeTenant, max)
	if err != nil {
		return err
	}

	for _, p := range polls {
		logger := log.WithFields(log.Fields{
			"action":     "PollStatusChanges",
			"poll":       p.ID.Hex(),
			"request_id": p.RequestID,
			"emulated":   p.Emulated != nil,
			"offer":      p.Offer,
			"applicant":  p.Name,
		})

		err = srv.checkUpdate(ctx, p.RequestID, model.PollingTypeTenant, p)

		switch {
		case err != nil:
			logger.WithError(err).Errorf("check status failed")
		case p.PDFID == "":
			logger.Warn("pdf was not downloaded")
		default:
			logger.WithFields(log.Fields{
				"risk_document": p.PDFURL,
				"profile_link":  p.ProfileLink,
				"risk":          p.RiskScore,
			}).Debug("checks complete")
		}
	}

	return nil
}
