package service

import (
	"bufio"
	"context"
	"net/http"
	"regexp"
	"strings"
	"time"

	"github.com/gocarina/gocsv"
	"gitlab.mashroom.com/mashroom/backend/common/generic/log"
	"gitlab.mashroom.com/mashroom/backend/identity/internal/model"
)

var letterRegexp = regexp.MustCompile(`\p{L}+`)

func letterGroups(s string) []string {
	return letterRegexp.FindAllString(strings.ToLower(s), -1)
}

func (srv *serviceImpl) UpdateSanctionList(ctx context.Context, url string) error {
	req, err := http.NewRequestWithContext(ctx, http.MethodGet, url, nil)
	if err != nil {
		return err
	}

	resp, err := srv.HTTPClient.Do(req)
	if err != nil {
		return err
	}

	defer func() {
		_ = resp.Body.Close()
	}()

	ver := time.Now()

	buf := bufio.NewReader(resp.Body)

	prefix := true

	for prefix {
		_, prefix, err = buf.ReadLine()
		if err != nil {
			return err
		}
	}

	err = gocsv.UnmarshalToCallback(buf, func(s *model.Sanction) {
		parts := []string{s.Name6, s.Name5, s.Name4, s.Name3, s.Name2, s.Name1}

		s.Version = ver
		s.Key = strings.ToLower(strings.Join(parts, " "))
		s.Search = nil

		for _, p := range parts {
			s.Search = append(s.Search, letterGroups(p)...)
		}

		err = srv.Repository.SanctionSave(ctx, s)
		if err != nil {
			log.WithError(err).Errorf("Importing sanction entry %+v", s)
		}
	})
	if err != nil {
		return err
	}

	err = srv.Repository.SanctionRemoveByMinVersion(ctx, ver)

	return err
}
